#!/bin/sh

#==============================================================================
#
#   Shell script to do daily wwwstats on log file and produce an HTML file
#   containing the NPAC site statistics
#
#   Ade Miller 8th Jan 96
#   Jake Kim 23th Jul 98 (Last modified)
#
#==============================================================================
#=======================================================
#
# These four definitions specify the binary paths for
# nova and outback and the writable document and log root
# for the web server.
#
#=======================================================
#
outback_bin=/srvtools/bin/stats
gz_bin=/usr/local/bin
docroot=/servers/npac_http/html
logroot=/servers/npac_http/log
tmp=$logroot/tmp

#
#   Name of log file to use:
#
logfile=$logroot/logs/access_log
#
#   Name of file to write this month's wwwstat results to:
#
wwwmonth=$docroot/stats/wwwstats.html
newmonth=$docroot/stats/month.html
npacmonth=$docroot/stats/npacmonth.html
syronlymonth=$docroot/stats/syronlymonth.html
#
#   Name of file to write longer, last 28 day wwwstat results to:
#
wwwresult=$docroot/stats/wwwstats_28.html
#
# Pulsar: 
#
wwwpulsar=$docroot/stats/wwwpulsar.html
#
#   Names of executable wwwstat program:
#
wwwstat=$outback_bin/outbackwwwstat
newwwwstat=$outback_bin/outbackwwwstat
# test for checking spider agents
test=$outback_bin/test
#
#   Name of file to write yesterday's wwwstat result to:
#
wwwday=$docroot/stats/wwwday.html
wwwdayurs=$docroot/stats/wwwdayurs.html
wwwsyr28=$docroot/stats/wwwsyr28.html
wwwnpac28=$docroot/stats/wwwnpac28.html
#
#
#
dayspider=$docroot/stats/dayspider.dat
monthspider=$docroot/stats/monthspider.dat
##tempspider=$docroot/stats/tempspider.dat
#==============================================================================

echo '['`date`'] wwwstat.sh: Starting'

\rm -f $tmp/*

## wwwtmp=$tmp/wwwstats.$$
newtmp=$tmp/newmonth.$$
tmpnpac=$tmp/npac.$$
tmpsyronly=$tmp/syronly.$$
latest_logs=`\ls $logroot/log_archive/access_log.* | tail -28`
month_logs=`\ls $logroot/log_archive/access_log.* | tail -30`
month_agent=`\ls $logroot/log_archive/agent_log.* | tail -30`
yesterday_log=`\ls $logroot/log_archive/access_log.* | tail -1`
yesterday_agent=`\ls $logroot/log_archive/agent_log.* | tail -1`
thisday=`date +%d`
thismonth=`date +%h`
thisyear=`date +%y`

#
# Remove all but this month's hits.  Remove any hits for today.
#

touch $tmp/log.$$
nice -8 $gz_bin/gunzip -c $month_logs | \
   nice -8 grep "[0-9]/$thismonth/19$thisyear" >> $tmp/log.$$

touch $tmp/syrlog.$$
nice -8 grep "\.syr\.edu -" $tmp/log.$$ >> $tmp/syrlog.$$

touch $tmp/npaclog.$$
nice -8 grep "npac\.syr\.edu" $tmp/syrlog.$$ >> $tmp/npaclog.$$

touch $tmp/syronlylog.$$
nice -8 grep -v "npac\.syr\.edu" $tmp/syrlog.$$ >> $tmp/syronlylog.$$

touch $tmp/log1.$$
nice -8 grep -v "$thisday/$thismonth/19$thisyear" $logfile >> $tmp/log1.$$

touch $tmp/log2.$$
nice -8 grep "pulsar" $tmp/log.$$ >> $tmp/log2.$$

touch $tmp/log3.$$
nice -8  $gz_bin/gunzip -c $yesterday_log >> $tmp/log3.$$

touch $tmp/log4.$$
nice -8 $gz_bin/gunzip -c $yesterday_log | grep "[0-9] - - \[" >> $tmp/log4.$$

touch $tmp/log_syr.$$
nice -8 $gz_bin/gunzip -c $latest_logs | \
    nice -8 grep "\.syr\.edu" >> $tmp/log_syr.$$

touch $tmp/log_npac.$$
nice -8 grep "npac\.syr\.edu" $tmp/log_syr.$$ >> $tmp/log_npac.$$

touch $tmp/log_syronly.$$
nice -8 grep -v "npac\.syr\.edu" $tmp/log_syr.$$ >> $tmp/log_syronly.$$

\rm -f $dayspider
touch $dayspider
touch $tmp/dayagent.$$
nice -8  $gz_bin/gunzip -c $yesterday_agent >> $tmp/dayagent.$$
nice -8 $test $tmp/dayagent.$$ | wc -l > $dayspider

\rm -f $monthspider
touch $monthspider
touch $tmp/monthagent.$$
nice -8  $gz_bin/gunzip -c $month_agent | grep "[0-9]/$thismonth/19$thisyear" \
   >> $tmp/monthagent.$$
nice -8 $test $tmp/monthagent.$$ | wc -l > $monthspider

## cp $tmp/dayagent.$$ $tempspider
## \rm -f $tempspider
echo '['`date`'] wwwstat.sh: searched log files'

\ls $logroot/log_archive/access_log.* | tail -28
wc -l $tmp/log.$$

#
# Create new uptodate wwwstats.html file by running another script.
#
# Build a stats file for this month only $wwwtmp.
# Build a stats file for last four weeks $wwwresult.
# Build a stats file for $wwwpulsar
#
nice -8 $wwwstat -U $tmp/log1.$$ $latest_logs > $wwwresult
echo '['`date`'] wwwstat.sh: built 28 day log'
## nice -8 $wwwstat -U $tmp/log.$$ > $wwwtmp
## echo '['`date`'] wwwstat.sh: built this months log'
# new monthly
if (test $thisday != "01") then
  nice -8 $newwwwstat -U $tmp/log.$$ > $newtmp		
  echo '['`date`'] wwwstat.sh: built new months log'
  nice -8 $newwwwstat -U $tmp/npaclog.$$ > $tmpnpac
  echo '['`date`'] wwwstat.sh: built npac monthly log'
  nice -8 $newwwwstat -U $tmp/syronlylog.$$ > $tmpsyronly
  echo '['`date`'] wwwstat.sh: built syronly monthly log'
fi
nice -8 $wwwstat -U $tmp/log2.$$ > $wwwpulsar
echo '['`date`'] wwwstat.sh: built for pulsar'
nice -8 $newwwwstat -U $tmp/log3.$$ > $wwwday
echo '['`date`'] wwwstat.sh: built yesterday log'
nice -8 $newwwwstat -u $tmp/log4.$$ > $wwwdayurs
echo '['`date`'] wwwstat.sh: built yesterday unresolved log'
nice -8 $newwwwstat -U $tmp/log_npac.$$ > $wwwnpac28
echo '['`date`'] wwwstat.sh: built npac 28 day log'
nice -8 $newwwwstat -U $tmp/log_syronly.$$ > $wwwsyr28
echo '['`date`'] wwwstat.sh: built syr_only 28 day log'

#\rm -f $dayspider
#touch $dayspider
#\wc -l $tmp/dayagent.$$ >> $dayspider

#\rm -f $monthspider
#touch $monthspider
#\wc -l $tmp/monthagent.$$ >> $monthspider

#
# Remove temporary files and copy result to HTML archive.
#
\rm -f $tmp/log.$$
\rm -f $tmp/log1.$$
\rm -f $tmp/log2.$$
\rm -f $tmp/log3.$$
\rm -f $tmp/log4.$$
\rm -f $tmp/log_syr.$$
\rm -f $tmp/log_syronly.$$
\rm -f $tmp/log_npac.$$
\rm -f $tmp/syrlog.$$
\rm -f $tmp/npaclog.$$
\rm -f $tmp/syronlylog.$$
\rm -f $tmp/dayagent.$$
\rm -f $tmp/monthagent.$$
## \mv -f $wwwtmp $wwwmonth
# New addition
if (test $thisday != "01") then
  \mv -f $newtmp $newmonth
  \mv -f $tmpnpac $npacmonth
  \mv -f $tmpsyronly $syronlymonth
fi
# Copy from New monthly html for safe execution of previous month version
\cp $newmonth $wwwmonth
chmod 664 $wwwresult
chmod 664 $wwwmonth
# New
chmod 664 $newmonth
chmod 664 $npacmonth
chmod 664 $syronlymonth
chmod 664 $wwwpulsar
chmod 664 $wwwday
chmod 664 $wwwdayurs
chmod 664 $wwwsyr28
chmod 664 $wwwnpac28

echo '['`date`'] wwwstat.sh: Finished'
exit
