#!/bin/sh 

#==============================================================================
#
#   Shell script to do monthly wwwstats on log file and produce an HTML file
#   containing the NPAC site statistics
#
#   Ade Miller 8th Jan 96
#
#   As the server has been changed, some environment sets have been changed.
#   Some codes for Y2K compliance have been added. (Valid up to 2060)
#
#   Jungkee (Jake) Kim 1th Jan 2000
#
#==============================================================================
#=======================================================
#
# These four definitions specify the binary paths for
# nova and clyde and the writable document and log root
# for the web server.
#
#=======================================================
#
outback_bin=/srvtools/bin/stats
docroot=/servers/npac_http/html
logroot=/servers/npac_http/log
gz_bin=/usr/local/bin
tmp=$logroot/tmp

#
#   Name of log file to use:
#
logfile=$logroot/logs/access_log
#
#   Name of file to write this month's wwwstat results to:
#
wwwhtml=$docroot/stats/archive
#
#   Names of executable wwwstat program:
#
wwwstat=$outback_bin/outbackwwwstat

#==============================================================================
echo '['`date`'] wwwstat_month.sh: Starting' 

latest_logs=`\ls $logroot/log_archive/access_log.* | tail -31`
thisday=`date +%d`
thismonth=`date +%h`
thisyear=`date +%y`

lastyear=$thisyear

case "$thismonth" in
  Jan) lastmonth="Dec"; 
    if (test $thisyear -lt 10) 
      then
        case "$thisyear" in
          00) lastyear="99";;
          01) lastyear="00";;
          02) lastyear="01";;
          03) lastyear="02";;
          04) lastyear="03";;
          05) lastyear="04";;
          06) lastyear="05";;
          07) lastyear="06";;
          08) lastyear="07";;
          09) lastyear="08";;
        esac
      else
        lastyear=`expr $thisyear - 1` 
    fi ;;
  Feb) lastmonth="Jan" ;;
  Mar) lastmonth="Feb" ;;
  Apr) lastmonth="Mar" ;;
  May) lastmonth="Apr" ;;
  Jun) lastmonth="May" ;;
  Jul) lastmonth="Jun" ;;
  Aug) lastmonth="Jul" ;;
  Sep) lastmonth="Aug" ;;
  Oct) lastmonth="Sep" ;;
  Nov) lastmonth="Oct" ;;
  Dec) lastmonth="Nov" ;;
esac
  
echo '['`date`'] wwwstat_month.sh: stats for '$lastmonth' '$lastyear

#
# Remove all but last month's hits.  Remove any hits for this month.
#

touch $tmp/log.$$
if (test $lastyear -gt 60) 
  then
    nice -9 \gunzip -c $latest_logs | \
     nice -9 grep "[0-9]/$lastmonth/19$lastyear" >> $tmp/log.$$
  else
    nice -9 \gunzip -c $latest_logs | \
     nice -9 grep "[0-9]/$lastmonth/20$lastyear" >> $tmp/log.$$
fi

#
# Create new uptodate wwwstats.html files by running wwwstat.
#
# 1: Build a stats file for this month only, [Month].[Year].wwwstats.html
# 2: Built a stats for this year, [Year].wwwstats.html, by merging this
#    month with existing yearly file. (Has some problem - Jake)
#    (Too slow and corrupted data result - Jake)

nice -9 $wwwstat -U $tmp/log.$$ > $wwwhtml/$lastmonth.$lastyear.wwwstats.html

#
# Remove temporary files and copy result to HTML archive.
#
\rm -f $tmp/log.$$
chmod 664 $wwwhtml/$lastyear.wwwstats.html
chmod 664 $wwwhtml/$lastmonth.$lastyear.wwwstats.html

cp $wwwhtml/$lastmonth.$lastyear.wwwstats.html $docroot/stats/month.html
chmod 664 $docroot/stats/month.html

echo '['`date`'] wwwstat_month.sh: Finished' 
exit
